/****************************************************************
 *								*
 * Copyright (c) 2001-2015 Fidelity National Information 	*
 * Services, Inc. and/or its subsidiaries. All rights reserved.	*
 *								*
 *	This source code contains the intellectual property	*
 *	of its copyright holder(s), and is made available	*
 *	under a license.  If you do not know the terms of	*
 *	the license, please stop and do not read further.	*
 *								*
 ****************************************************************/

#ifndef DOLLARH_INCLUDED
#define DOLLARH_INCLUDED

long dollarh(time_t intime, uint4 *days, time_t *seconds);

#endif /* DOLLARH_INCLUDED */
